# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Copyright 2014 Canonical Ltd.
# Author: Omer Akram <omer.akram@canonical.com>
#
# This file is part of ubuntu-integration-tests.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

"""Helper functions to make writing Inter-app integration tests easier."""

from autopilot.introspection import get_proxy_object_for_existing_process
from ubuntuuitoolkit import emulators as toolkit_emulators
from unity8.shell.emulators import UnityEmulatorBase

import subprocess
import time


def get_proxy_object_by_process_name(proc_name):
    return get_proxy_object_for_existing_process(
        _get_pid_by_name(proc_name),
        emulator_base=_get_emulator_base(proc_name)
    )


def _get_pid_by_name(proc_name):
        for i in range(10):
            try:
                return int(
                    subprocess.check_output(['pidof', proc_name]).strip())
            except subprocess.CalledProcessError:
                # application not started yet, check in a second
                time.sleep(1)


def _get_emulator_base(proc_name):
    if proc_name == 'unity8':
        return UnityEmulatorBase
    else:
        return toolkit_emulators.UbuntuUIToolkitEmulatorBase
