# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Copyright 2014 Canonical
#
# This file is part of ubuntu-integration-tests.
#
# ubuntu-integration-tests is free software: you can redistribute it and/or
# modify it under the terms of the GNU General Public License version 3, as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

from time import sleep
import uuid

from autopilot import platform
from autopilot.input import Touch, Pointer
from ubuntu_integration_tests import helpers, tests
from ubuntu_integration_tests.emulators.dash import AlesageDash
from unity8.process_helpers import unlock_unity
from unity8.shell.tests import UnityTestCase, _get_device_emulation_scenarios


class UbuntuOneIntegrationTestCase(tests.IntegrationTestCase):

    def setUp(self):
        super(UbuntuOneIntegrationTestCase, self).setUp()

    def get_unique_email_address(self):
        return 'u1test+{}@canonical.com'.format(uuid.uuid4())

    def open_system_settings(self):
        pass
        #raise NotImplementedError('TODO')

    def return_to_home_screen(self):
        pass
        #raise NotImplementedError('TODO')

    def assert_app_is_running(self, app_name):
        pass
        #raise NotImplementedError('TODO')

    def test_create_ubuntuone_user_install_app(self):
        # generate unique user info
        user_email = self.get_unique_email_address()
        user_password = 'password'
        user_name = 'user'

        # navigate to u1 accounts and create a new user
        system_settings = self.open_system_settings()
        online_accounts = system_settings.open_online_accounts()
        u1_accounts = online_accounts.open_u1_accounts()
        u1_accounts.fill_form(user_email, user_password, user_name)
        u1_accounts.create_account()
        
        # exit u1 accounts
        self.return_to_homescreen()

        # navigate to apps scope, navigate to suggested apps and select an app to install
        dash_apps = self.dash.open_scope('clickscope')
        applications = dash_apps.get_applications('appstore')
        try:
            selected_app = applications[0]
        except KeyError:
            self.fail('No applications found.')
        dash_apps.open_preview('appstore', selected_app.title)

        # install app and then launch it
        selected_app.press_install()
        selected_app.wait_for_install_complete()
        selected_app.open_app()

        # assert the app is running
        self.assert_app_is_running(selected_app_name)
